@@ -1,4 +1,6 @@
+// -*- mode: C++; indent-tabs-mode: nil; -*-
 // Workspacemenu.cc for Blackbox - an X11 Window manager
+// Copyright (c) 2001 - 2002 Sean 'Shaleh' Perry <shaleh@debian.org>
 // Copyright (c) 1997 - 2000 Brad Hughes (bhughes@tcac.net)
 //
 // Permission is hereby granted, free of charge, to any person obtaining a
@@ -19,12 +21,6 @@
 // FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 // DEALINGS IN THE SOFTWARE.
 
-// stupid macros needed to access some functions in version 2 of the GNU C
-// library
-#ifndef   _GNU_SOURCE
-#define   _GNU_SOURCE
-#endif // _GNU_SOURCE
-
 #ifdef    HAVE_CONFIG_H
 #  include "../config.h"
 #endif // HAVE_CONFIG_H
@@ -38,46 +34,28 @@
 
 
 Workspacemenu::Workspacemenu(BScreen *scrn) : Basemenu(scrn) {
-  screen = scrn;
-
   setInternalMenu();
 
-  setLabel(i18n->getMessage(
-#ifdef    NLS
-			    WorkspacemenuSet, WorkspacemenuWorkspacesTitle,
-#else // !NLS
-			    0, 0,
-#endif // NLS
-			    "Workspaces"));
-
-  insert(i18n->getMessage(
-#ifdef    NLS
-			  WorkspacemenuSet, WorkspacemenuNewWorkspace,
-#else // !NLS
-			  0, 0,
-#endif // NLS
-			  "New Workspace"));
-  insert(i18n->getMessage(
-#ifdef    NLS
-			  WorkspacemenuSet, WorkspacemenuRemoveLast,
-#else // !NLS
-			  0, 0,
-#endif // NLS
-			  "Remove Last"));
+  setLabel(i18n(WorkspacemenuSet, WorkspacemenuWorkspacesTitle, "Workspaces"));
+  insert(i18n(WorkspacemenuSet, WorkspacemenuNewWorkspace, "New Workspace"));
+  insert(i18n(WorkspacemenuSet, WorkspacemenuRemoveLast, "Remove Last"));
 }
 
 
-void Workspacemenu::itemSelected(int button, int index) {
-  if (button == 1) {
-    if (index == 0)
-      screen->addWorkspace();
-    else if (index == 1)
-      screen->removeLastWorkspace();
-    else if ((screen->getCurrentWorkspace()->getWorkspaceID() !=
-	      (index - 2)) && ((index - 2) < screen->getCount()))
-      screen->changeWorkspaceID(index - 2);
+void Workspacemenu::itemSelected(int button, unsigned int index) {
+  if (button != 1)
+    return;
 
-    if (! (screen->getWorkspacemenu()->isTorn() || isTorn()))
-      hide();
+  if (index == 0) {
+    getScreen()->addWorkspace();
+  } else if (index == 1) {
+    getScreen()->removeLastWorkspace();
+  } else {
+    index -= 2;
+    const Workspace* const wkspc = getScreen()->getCurrentWorkspace();
+    if (wkspc->getID() != index && index < getScreen()->getWorkspaceCount())
+      getScreen()->changeWorkspaceID(index);
   }
+  if (! (getScreen()->getWorkspacemenu()->isTorn() || isTorn()))
+    hide();
 }
